@@ -14,7 +14,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Type
+from typing import Any, Dict, List, Type, Union
 
 from botocore.client import ClientMeta
 
@@ -79,7 +79,7 @@ class Exceptions:
 
 class ComputeOptimizerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html)
     """
 
@@ -88,7 +88,9 @@ class ComputeOptimizerClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#can_paginate)
         """
 
@@ -96,72 +98,82 @@ class ComputeOptimizerClient:
         self,
         *,
         jobIds: List[str] = None,
-        filters: List[JobFilterTypeDef] = None,
+        filters: List["JobFilterTypeDef"] = None,
         nextToken: str = None,
         maxResults: int = None
     ) -> DescribeRecommendationExportJobsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
+        Describes recommendation export jobs created in the last seven days.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#describe_recommendation_export_jobs)
         """
 
     def export_auto_scaling_group_recommendations(
         self,
         *,
-        s3DestinationConfig: S3DestinationConfigTypeDef,
+        s3DestinationConfig: "S3DestinationConfigTypeDef",
         accountIds: List[str] = None,
-        filters: List[FilterTypeDef] = None,
+        filters: List["FilterTypeDef"] = None,
         fieldsToExport: List[ExportableAutoScalingGroupFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None
     ) -> ExportAutoScalingGroupRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
+        Exports optimization recommendations for Auto Scaling groups.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_auto_scaling_group_recommendations)
         """
 
     def export_ebs_volume_recommendations(
         self,
         *,
-        s3DestinationConfig: S3DestinationConfigTypeDef,
+        s3DestinationConfig: "S3DestinationConfigTypeDef",
         accountIds: List[str] = None,
-        filters: List[EBSFilterTypeDef] = None,
+        filters: List["EBSFilterTypeDef"] = None,
         fieldsToExport: List[ExportableVolumeFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None
     ) -> ExportEBSVolumeRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ebs_volume_recommendations)
+        Exports optimization recommendations for Amazon EBS volumes.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ebs_volume_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_ebs_volume_recommendations)
         """
 
     def export_ec2_instance_recommendations(
         self,
         *,
-        s3DestinationConfig: S3DestinationConfigTypeDef,
+        s3DestinationConfig: "S3DestinationConfigTypeDef",
         accountIds: List[str] = None,
-        filters: List[FilterTypeDef] = None,
+        filters: List["FilterTypeDef"] = None,
         fieldsToExport: List[ExportableInstanceFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None
     ) -> ExportEC2InstanceRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
+        Exports optimization recommendations for Amazon EC2 instances.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_ec2_instance_recommendations)
         """
 
     def export_lambda_function_recommendations(
         self,
         *,
-        s3DestinationConfig: S3DestinationConfigTypeDef,
+        s3DestinationConfig: "S3DestinationConfigTypeDef",
         accountIds: List[str] = None,
-        filters: List[LambdaFunctionRecommendationFilterTypeDef] = None,
+        filters: List["LambdaFunctionRecommendationFilterTypeDef"] = None,
         fieldsToExport: List[ExportableLambdaFunctionFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None
     ) -> ExportLambdaFunctionRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_lambda_function_recommendations)
+        Exports optimization recommendations for AWS Lambda functions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_lambda_function_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_lambda_function_recommendations)
         """
 
@@ -173,7 +185,9 @@ class ComputeOptimizerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#generate_presigned_url)
         """
 
@@ -184,10 +198,12 @@ class ComputeOptimizerClient:
         autoScalingGroupArns: List[str] = None,
         nextToken: str = None,
         maxResults: int = None,
-        filters: List[FilterTypeDef] = None
+        filters: List["FilterTypeDef"] = None
     ) -> GetAutoScalingGroupRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
+        Returns Auto Scaling group recommendations.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_auto_scaling_group_recommendations)
         """
 
@@ -197,11 +213,13 @@ class ComputeOptimizerClient:
         volumeArns: List[str] = None,
         nextToken: str = None,
         maxResults: int = None,
-        filters: List[EBSFilterTypeDef] = None,
+        filters: List["EBSFilterTypeDef"] = None,
         accountIds: List[str] = None
     ) -> GetEBSVolumeRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ebs_volume_recommendations)
+        Returns Amazon Elastic Block Store (Amazon EBS) volume recommendations.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ebs_volume_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ebs_volume_recommendations)
         """
 
@@ -211,11 +229,13 @@ class ComputeOptimizerClient:
         instanceArns: List[str] = None,
         nextToken: str = None,
         maxResults: int = None,
-        filters: List[FilterTypeDef] = None,
+        filters: List["FilterTypeDef"] = None,
         accountIds: List[str] = None
     ) -> GetEC2InstanceRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
+        Returns Amazon EC2 instance recommendations.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ec2_instance_recommendations)
         """
 
@@ -225,17 +245,23 @@ class ComputeOptimizerClient:
         instanceArn: str,
         stat: MetricStatisticType,
         period: int,
-        startTime: datetime,
-        endTime: datetime
+        startTime: Union[datetime, str],
+        endTime: Union[datetime, str]
     ) -> GetEC2RecommendationProjectedMetricsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
+        Returns the projected utilization metrics of Amazon EC2 instance
+        recommendations.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ec2_recommendation_projected_metrics)
         """
 
     def get_enrollment_status(self) -> GetEnrollmentStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
+        Returns the enrollment (opt in) status of an account to the AWS Compute
+        Optimizer service.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_enrollment_status)
         """
 
@@ -244,12 +270,14 @@ class ComputeOptimizerClient:
         *,
         functionArns: List[str] = None,
         accountIds: List[str] = None,
-        filters: List[LambdaFunctionRecommendationFilterTypeDef] = None,
+        filters: List["LambdaFunctionRecommendationFilterTypeDef"] = None,
         nextToken: str = None,
         maxResults: int = None
     ) -> GetLambdaFunctionRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_lambda_function_recommendations)
+        Returns AWS Lambda function recommendations.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_lambda_function_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_lambda_function_recommendations)
         """
 
@@ -257,7 +285,9 @@ class ComputeOptimizerClient:
         self, *, accountIds: List[str] = None, nextToken: str = None, maxResults: int = None
     ) -> GetRecommendationSummariesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
+        Returns the optimization findings for an account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_recommendation_summaries)
         """
 
@@ -265,6 +295,9 @@ class ComputeOptimizerClient:
         self, *, status: StatusType, includeMemberAccounts: bool = None
     ) -> UpdateEnrollmentStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
+        Updates the enrollment (opt in and opt out) status of an account to the AWS
+        Compute Optimizer service.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#update_enrollment_status)
         """
